##  Adding Drill-Downs to a Template
Drill-downs show a visual hierarchy or expansion of detail, such as parent-child structures.
  1. Right-click the source fact sheet type.
  2. In the menu, choose Drill-Downs and select the drill-down type.
For example, “Organizations.”


Applying a Drill-Down to a Template
![A gif of the template editor with an application node at the center. An organization is selected as the drill-down.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio317f640fecd84e0d9701bb3e8e8727c7_LowRes.gif)
